@@ -182,15 +182,8 @@ class KeycloakAdmin:
         :return: user_id
         """
 
-        data_raw = self.get_users(query={"username": username})
-        data_content = raise_error_from_response(data_raw, KeycloakGetError)
-
-        for user in data_content:
-            this_use_rname = json.dumps(user["username"]).strip('"')
-            if this_use_rname == username:
-                return json.dumps(user["id"]).strip('"')
-
-        return None
+        users = self.get_users(query={"username": username})
+        return next((user["id"] for user in users if user["username"] == username), None)
 
     def get_user(self, user_id):
         """
@@ -386,7 +379,7 @@ class KeycloakAdmin:
                     return self.get_subgroups(subgroup, path)
         return None
 
-    def get_group_members(self, group_id):
+    def get_group_members(self, group_id, **query):
         """
         Get members by group id. Returns group members
 
@@ -396,7 +389,7 @@ class KeycloakAdmin:
         :return: Keycloak server response (UserRepresentation)
         """
         params_path = {"realm-name": self.realm_name, "id": group_id}
-        data_raw = self.connection.raw_get(URL_ADMIN_GROUP_MEMBERS.format(**params_path))
+        data_raw = self.connection.raw_get(URL_ADMIN_GROUP_MEMBERS.format(**params_path), **query)
         return raise_error_from_response(data_raw, KeycloakGetError)
 
     def get_group_by_path(self, path, search_in_subgroups=False):
@@ -780,6 +773,61 @@ class KeycloakAdmin:
                                               data=json.dumps(payload))
         return raise_error_from_response(data_raw, KeycloakGetError, expected_code=204)
 
+    def get_authentication_flows(self):
+        """
+        Get authentication flows. Returns all flow details
+
+        AuthenticationFlowRepresentation
+        https://www.keycloak.org/docs-api/4.1/rest-api/index.html#_authenticationflowrepresentation
+
+        :return: Keycloak server response (AuthenticationFlowRepresentation)
+        """
+        params_path = {"realm-name": self.realm_name}
+        data_raw = self.connection.raw_get(URL_ADMIN_FLOWS.format(**params_path))
+        return raise_error_from_response(data_raw, KeycloakGetError)
+
+    def create_authentication_flow(self, payload, skip_exists=False):
+        """
+        Create a new authentication flow
+
+        AuthenticationFlowRepresentation
+        https://www.keycloak.org/docs-api/4.1/rest-api/index.html#_authenticationflowrepresentation
+
+        :param payload: AuthenticationFlowRepresentation
+        :return: Keycloak server response (RoleRepresentation)
+        """
+
+        params_path = {"realm-name": self.realm_name}
+        data_raw = self.connection.raw_post(URL_ADMIN_FLOWS.format(**params_path),
+                                            data=payload)
+        return raise_error_from_response(data_raw, KeycloakGetError, expected_code=201, skip_exists=skip_exists)
+
+    def get_authentication_flow_executions(self, flow_alias):
+        """
+        Get authentication flow executions. Returns all execution steps
+
+        :return: Response(json)
+        """
+        params_path = {"realm-name": self.realm_name, "flow-alias": flow_alias}
+        data_raw = self.connection.raw_get(URL_ADMIN_FLOWS_EXECUTIONS.format(**params_path))
+        return raise_error_from_response(data_raw, KeycloakGetError)
+
+    def update_authentication_flow_executions(self, payload, flow_alias):
+        """
+        Update an authentication flow execution
+
+        AuthenticationExecutionInfoRepresentation
+        https://www.keycloak.org/docs-api/4.1/rest-api/index.html#_authenticationexecutioninforepresentation
+
+        :param payload: AuthenticationExecutionInfoRepresentation
+        :return: Keycloak server response
+        """
+
+        params_path = {"realm-name": self.realm_name, "flow-alias": flow_alias}
+        data_raw = self.connection.raw_put(URL_ADMIN_FLOWS_EXECUTIONS.format(**params_path),
+                                            data=payload)
+        return raise_error_from_response(data_raw, KeycloakGetError, expected_code=204)
+
     def sync_users(self, storage_id, action):
         """
         Function to trigger user sync from provider
